//
//  UserInfo.m
//  FacebookOAuth
//
//  Created by Reid Simonton on 2/6/14.
//  Copyright (c) 2014 Temboo, Inc. All rights reserved.
//

#import "UserInfo.h"
#import "TMBFacebook.h"

@implementation UserInfo

@synthesize authorizationUrl;
@synthesize js;
@synthesize oauthHelper;
@synthesize webView;

-(void)choreographyDidFailWithError:(NSError *)error {
    NSLog(@"%s - An error occurred: %@", __PRETTY_FUNCTION__, error);
}

-(void)choreographyDidFinishExecuting:(id)result {
    //NSLog(@"%s - Got user details: %@", __PRETTY_FUNCTION__, [result getResponse]);
    
    NSError *error = nil;
    NSData *jsonData = [[result getResponse] dataUsingEncoding:NSUTF8StringEncoding];
    
    id user = [NSJSONSerialization JSONObjectWithData:jsonData options:0 error:&error];
    JSValue *displayUserInfo = self.js[@"displayUserInfo"];
    [displayUserInfo callWithArguments:@[user]];
}

-(void)jsFinalizeOAuth {
    NSLog(@"Finalizing OAuth");
    [self.oauthHelper finalizeOAuthForDelegate:self];
}

-(void)jsLog:(NSString*)msg {
    NSLog(@"JavaScript: %@", msg);
}

-(void)oauthDidFinalize:(NSString*)accessToken {
    //NSLog(@"%s - Got user access token: %@", __PRETTY_FUNCTION__, accessToken);
    
    TMBFacebook_Reading_User *choreo = [[TMBFacebook_Reading_User alloc] initWithSession:[self.oauthHelper getUserSession]];
    TMBFacebook_Reading_User_Inputs *inputs = [[TMBFacebook_Reading_User_Inputs alloc] init];
    
    [inputs setAccessToken:accessToken];
    
    [choreo executeWithInputs:inputs delegate:self];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    // Initialize UIWebView delegate
    [self.webView setDelegate:self];
    
    NSLog(@"Loading web page: %@", self.authorizationUrl);
    NSURL *url = [NSURL URLWithString:self.authorizationUrl];
    NSURLRequest *request = [NSURLRequest requestWithURL:url];
    [self.webView loadRequest:request];
}

- (void)webViewDidFinishLoad:(UIWebView *)view{
    //NSLog(@"%s - %@", __PRETTY_FUNCTION__, [view stringByEvaluatingJavaScriptFromString:@"window.location.href"]);
    // Ask JavaScript for the page's URL
    NSString *hostname = [view stringByEvaluatingJavaScriptFromString:@"window.location.hostname"];
    
    if([hostname isEqualToString:@"localhost"]){
        // This is our redirect URL, the user has authorized the app and has been redirected back here
        NSLog(@"Finalizing OAuth");
        
        // Retrieve and initialize our JS context
        NSLog(@"Initializing JavaScript context");
        self.js = [self.webView valueForKeyPath:@"documentView.webView.mainFrame.javaScriptContext"];
        self.js[@"ios"] = self;
        
        // Finalize the OAuth flow
        [self.js evaluateScript:@"finalizeOAuth();"];
    }
}

- (void)webViewDidStartLoad:(UIWebView *)view{
    NSLog(@"%s - %@", __PRETTY_FUNCTION__, [view stringByEvaluatingJavaScriptFromString:@"window.location.href"]);
}

- (void)webView:(UIWebView *)view didFailLoadWithError:(NSError *)error{
    NSLog(@"%s - %@", __PRETTY_FUNCTION__, error);
}

@end
